@@ -99,3 +99,18 @@ def do_put_request(url, token=None, json=None, data=None, headers=None, school_i
     finally:
         if resp:
             resp.close()
+
+
+def do_delete_request(url, token=None, json=None, data=None, headers=None, school_in_header=None):
+    """send http delete request"""
+    headers = _get_request_headers(headers=headers, token=token, school=school_in_header)
+    resp = None
+    try:
+        resp = requests.delete(url=url, json=json, data=data, headers=headers, timeout=(CONNECT_TIMEOUT, READ_TIMEOUT))
+        return resp_parse_process(resp=resp)
+    except Exception as e:
+        logger.error("Error: {}, Detail: {}".format(sys._getframe().f_code.co_name, e))
+        return resp_parse_process()
+    finally:
+        if resp:
+            resp.close()
