@@ -31,25 +31,31 @@ def upload_meeting_attendance(content):
     last_record_time = attendance_data['last_record_time']
     record_time = record_time.replace("T", " ")
     last_record_time = last_record_time.replace("T", " ")
-    if not (record_time and meet_no and user_num):
+    if not (record_time and user_num):
         logger.info(">>> Meeting Attendance Lost Info :{}".format(attendance_id))
         return
     conn, cur = get_mssql_connection()
-    sql = "SELECT ID, REALSTART, REALEND FROM M_Meeting_Man_Out " \
-          "WHERE MeetNo='{}' AND OutId='{}' ORDER BY ID".format(meet_no, user_num)
-    cur.execute(sql)
-    result = cur.fetchone()
-    record_id, start, end = result[0], result[1], result[2]
-    start_date = date2str(start.date())
-    set_start = start_date == "1900-01-01"
-    if set_start:
-        record_status = status_map.get(status)
-        update_sql = "UPDATE M_Meeting_Man_Out SET REALSTART='{}', STARTSTATUS={} " \
-                     "WHERE ID={}".format(record_time, record_status, record_id)
-    else:
-        update_sql = "UPDATE M_Meeting_Man_Out SET REALEND='{}', ENDSTATUS={} " \
-                     "WHERE ID={}".format(last_record_time, 1, record_id)
-    cur.execute(update_sql)
+    if meet_no:
+        sql = "SELECT ID, REALSTART, REALEND FROM M_Meeting_Man_Out " \
+              "WHERE MeetNo='{}' AND OutId='{}' ORDER BY ID".format(meet_no, user_num)
+        cur.execute(sql)
+        result = cur.fetchone()
+        record_id, start, end = result[0], result[1], result[2]
+        start_date = date2str(start.date())
+        set_start = start_date == "1900-01-01"
+        if set_start:
+            record_status = status_map.get(status)
+            update_sql = "UPDATE M_Meeting_Man_Out SET REALSTART='{}', STARTSTATUS={} " \
+                         "WHERE ID={}".format(record_time, record_status, record_id)
+        else:
+            update_sql = "UPDATE M_Meeting_Man_Out SET REALEND='{}', ENDSTATUS={} " \
+                         "WHERE ID={}".format(last_record_time, 1, record_id)
+        cur.execute(update_sql)
+        conn.commit()
+    create_sql = "INSERT INTO M_ID_Record_Out(ECODE,OUTID,Poscode,OPERTIME,RECTYPE,IOFLAG,UpDateFlag,UpDateDT) " \
+                 "VALUES('{}','{}','{}','{}','{}','{}','{}','{}')". \
+        format("00000000", user_num, "1234", record_time, 17, 0, 0, record_time)
+    cur.execute(create_sql)
     conn.commit()
     cur.close()
     conn.close()
