@@ -13,15 +13,15 @@ class Processor(object):
     KIND_FUNC = {}
 
     @classmethod
-    def distribute(cls, topic, payload, school_id):
+    def distribute(cls, topic, payload):
         try:
             data = payload['data']
-            kind, content = data["kind"], data["extra"]
+            kind, content = data["kind"], data.get("extra", None) or data
         except (Exception,):
             return None
         try:
             if kind in cls.KIND_FUNC:
-                getattr(cls, cls.KIND_FUNC[kind])(school_id=school_id, content=content)
+                getattr(cls, cls.KIND_FUNC[kind])(content=content)
                 return TaskResult.SUCCESS
         except (Exception,):
             logger.error(traceback.print_exc())
