@@ -12,9 +12,14 @@ class NoticeSync(BaseSync):
 
     def crawl(self):
         for page in self.page_list:
+            print(">>> start crawl {}".format(page))
             ns = NoticeSpider(page[0], page[1])
             ns.start()
             for target in ns.targets.values():
+                if not target.get("content", None):
+                    continue
+                if not target.get("topic", None):
+                    continue
                 notice = Notice(title=target["topic"], content=target["content"])
                 self.notice.append(notice)
 
