@@ -96,6 +96,40 @@ class CourseTableSync(BaseSync):
                 num = index + int(r_info[-1])
                 positions.append((num, week))
             result = {'begin_week': begin_week, 'end_week': end_week, 'single': single, "positions": positions}
+        except (Exception,) as e:
+            result = self.analyse_sksj_b(sksj)
+            return result
+        return result
+
+    def analyse_sksj_b(self, sksj):
+        try:
+            if "星期" not in sksj:
+                return None
+            week_map = {"一": 1, "二": 2, "三": 3, "四": 4, "五": 5, "六": 6, "日": 7}
+            index_map = {"上午": 0, "下午": 4, "晚上": 8}
+            sksj_split = sksj.split(":")
+            week_range = sksj_split[0][1:-1].split("-")
+            begin_week, end_week = int(week_range[0]), int(week_range[1])
+            schedule_info = sksj_split[1]
+            single = 0
+            if "单周" in schedule_info:
+                single = 1
+            elif "双周" in schedule_info:
+                single = 2
+            position_info = schedule_info.split("  ")[-1].split(",")
+            positions = []
+            for info in position_info:
+                r_info = info[1:] if info[0] == ' ' else info
+                week = week_map.get(r_info[2], None)
+                index = index_map.get(r_info[4:6], 0)
+                try:
+                    begin_num, end_num = index + int(r_info[6]), index + int(r_info[10])
+                except (ValueError,):
+                    index = index_map.get(r_info[5:7], 0)
+                    begin_num, end_num = index + int(r_info[7]), index + int(r_info[7])
+                for num in range(begin_num, end_num + 1):
+                    positions.append((num, week))
+            result = {'begin_week': begin_week, 'end_week': end_week, 'single': single, "positions": positions}
         except (Exception,) as e:
             self.record("{}\n".format(sksj))
             return None
@@ -274,10 +308,10 @@ class CourseTableSync(BaseSync):
                 single = single_map.get(single_sign, 0)
                 week, num_range = row["XQJ"], row["JC"]
                 group_name, teacher_number = row["JYDW"], row["JSBH1"]
-                if not (classroom_name and week and num_range):
+                if not (classroom_name and begin_week and end_week and week and num_range):
                     continue
-                begin_week = begin_week.replece("第", "").replece("周", "")
-                end_week = end_week.replece("第", "").replece("周", "")
+                begin_week = begin_week.replace("第", "").replace("周", "")
+                end_week = end_week.replace("第", "").replace("周", "")
                 begin_week, end_week = int(begin_week), int(end_week)
                 classroom_num = self.bks_classroom_map.get(classroom_name, None) or get_md5_hash(classroom_name)
                 num_list = self.analyse_rent_num(num_range)
@@ -344,4 +378,4 @@ class CourseTableSync(BaseSync):
         dir_path = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
         file_path = os.path.join(dir_path, "course_info.txt")
         with open(file_path, "a+") as f:
-            f.write("{} >>> {} \n".format(now, info))
+            f.write("{} >>> {} \n".format(now, info))
\ No newline at end of file
